import numpy as np
import matplotlib.pyplot as plt
# This script has been originally written and tested with Python 3.5.2, but it should work for any reasonably new version of Python 2 and 3.

# Run this script with    
#    python plot.py
# or
#    python3 plot.py

# To run this code, you need to have packages "numpy" and "matplotlib" installed.
# On Unix-based systems, you can do this with following bash commands:
# For Python 2 paste into terminal:
# sudo apt-get install python-pip  
# sudo pip install numpy
# sudo pip install matplotlib

# For Python 3 paste into terminal:
# sudo apt-get install python3-numpy
# sudo apt-get install python3-matplotlib

r = np.loadtxt('./data/grid_in_r_and_b.txt')
b = np.loadtxt('./data/grid_in_r_and_b.txt')
Y = np.loadtxt('./data/grid_in_Y.txt')
N = np.loadtxt('./data/N(r,b,Y).txt')

def plot_vsr(b_index, Y, save_values_of_N):
    coordinate = str(b[b_index])
    if len(str(b[b_index])) > 6:
        if str(b[b_index])[-3] == 'e':
            coordinate = str(b[b_index])[:4] + str(b[b_index])[-3:]
        elif str(b[b_index])[-4] == 'e':
            coordinate = str(b[b_index])[:4] + str(b[b_index])[-4:]
        elif str(b[b_index])[-5] == 'e':
            coordinate = str(b[b_index])[:4] + str(b[b_index])[-5:]
        else:
            coordinate = str(b[b_index])[:4]
    plt.plot(r, N[int(10.*Y*len(r) + 0.3):int((10.*Y + 1.)*len(r) + 0.3), b_index], label='Y = ' + str(Y))
    axes = plt.gca()

    # Change here for different limits of axes
    # axes.set_xlim([0.01, 100.])
    # axes.set_ylim([0., 1.])

    if save_values_of_N:
        np.savetxt('plots/txt/bdepN_vsr_at_b' + coordinate + ',Y' + str(Y) + '.txt', N[int(10.*Y*len(r) + 0.3):int((10.*Y + 1.)*len(r) + 0.3), b_index])

    plt.ylabel('N(r, b = ' + coordinate + '[GeV$^{-1}$], Y = ' + str(Y) + ')')
    plt.xlabel('r [GeV$^{-1}$]')
    plt.title('Scattering amplitude for b = ' + coordinate + ' [GeV$^{-1}$], Y = ' + str(Y))
    plt.xscale('log')
    plt.savefig('plots/eps/bdepN_vsr_at_b' + coordinate + ',Y' + str(Y) + '.eps', format='eps', dpi=1000)
    plt.savefig('plots/png/bdepN_vsr_at_b' + coordinate + ',Y' + str(Y) + '.png')
    plt.close()
    return True

def plot_vsb(r_index, Y, save_values_of_N):
    coordinate = str(r[r_index])
    if len(str(r[r_index])) > 6:
        if str(r[r_index])[-3] == 'e':
            coordinate = str(r[r_index])[:4] + str(r[r_index])[-3:]
        elif str(r[r_index])[-4] == 'e':
            coordinate = str(r[r_index])[:4] + str(r[r_index])[-4:]
        elif str(r[r_index])[-5] == 'e':
            coordinate = str(r[r_index])[:4] + str(r[r_index])[-5:]
        else:
            coordinate = str(r[r_index])[:4]
    plt.plot(r, N[r_index + int(10.*Y*len(r) + 0.3)][:], label='Y = ' + str(Y))
    plt.ylabel('N(r = ' + coordinate + ' [GeV$^{-1}$], b, Y = ' + str(Y) + ')')
    plt.xlabel('b [GeV$^{-1}$]')
    plt.title('Scattering amplitude for r = ' + coordinate + ' [GeV$^{-1}$], Y = ' + str(Y))
    plt.xscale('log')
    plt.yscale('log')
    axes = plt.gca()

    if save_values_of_N:
        np.savetxt('plots/txt/bdepN_vsb_at_r' + coordinate + ',Y' + str(Y) + '.txt', N[r_index + int(10.*Y*len(r) + 0.3)][:])

    # Change here for different limits of axes
    # axes.set_xlim([0.1, 100.])
    # axes.set_ylim([10**-5, 10**0])

    plt.savefig('plots/eps/bdepN_vsb_at_r' + coordinate + ',Y' + str(Y) + '.eps', format='eps', dpi=1000)
    plt.savefig('plots/png/bdepN_vsb_at_r' + coordinate + ',Y' + str(Y) + '.png')
    plt.close()
    return True


# Insert here an integer index of the value of r/b from the grid that you would like to plot the grid starts at 10**-7 [1/GeV] and goes up to 10**2 [1/GeV].
# The grid is in log10 and has 226 steps. Each 25 steps are an orger of magnitude. So r = 10 [1/GeV] is r_index=200, r = 1 [1/GeV] is r_index=175 and r = 0.1 [1/GeV] is r_index=150. The same holds for b.
# Insert a float value of rapidity you wish to plot. It has to be an non-negative even multiple of 0.1 (such as 0.2, 0., 1.2, 3.4 etc.)
# If you wish to save the values of the scattering amplitude for your setup, chage the variable "save_values_of_N" to True and find them in the "plots/txt" folder.
plot_vsb(r_index=175, Y=0.2, save_values_of_N=False)
plot_vsr(b_index=100, Y=1.1, save_values_of_N=False)
# Plots will be saved in folder "plots"